"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Rules;
(function (Rules) {
    /**
     * 关闭规则
     */
    Rules[Rules["OFF"] = 0] = "OFF";
    /**
     * 开启规则 使用警告级别的错误：warn (不会导致程序退出)
     */
    Rules[Rules["WARN"] = 1] = "WARN";
    /**
     * 开启规则 使用错误级别的错误：error (当被触发的时候，程序会退出)
     */
    Rules[Rules["ERROR"] = 2] = "ERROR";
})(Rules = exports.Rules || (exports.Rules = {}));
const isProduction = process.env.NODE_ENV === 'production';
/**
 * Vue eslint 规则
 */
module.exports = {
    root: true,
    env: {
        node: true
    },
    // 允许使用全局变量 将变量设置为 true 将允许变量被重写，false 将不允许被重写。
    globals: {
        lib: false,
        wx: false,
        $: false,
        rrc: true,
        rc: true,
        rcLog: true,
        angular: false,
        FormData: false,
        debugger: false,
        Image: false
    },
    extends: [
        'plugin:vue/essential',
        require.resolve('eslint-config-standard')
    ],
    rules: {
        // 箭头函数有一个参数时可以省略括号
        'arrow-parens': Rules.OFF,
        // 不允许使用分号
        semi: [Rules.ERROR, 'never'],
        // 代码长度 最大是200
        'max-len': [Rules.ERROR, 200, 2],
        // allow async-await
        'generator-star-spacing': Rules.OFF,
        // function 括号之前 可以不用空格
        'space-before-function-paren': Rules.WARN,
        'padded-blocks': Rules.WARN,
        'no-var': Rules.ERROR,
        'no-unused-vars': ['error', {
                'caughtErrors': 'none',
                'argsIgnorePattern': '^_|h',
                'ignoreRestSiblings': true
            }],
        // 允许空的reject
        'prefer-promise-reject-errors': [Rules.ERROR, {
                allowEmptyReject: true
            }],
        // 允许对象属性中 不写驼峰 主要是用于 给后端 传值或者显示后端传输回来的值
        camelcase: [Rules.ERROR, {
                properties: 'never'
            }],
        // 字符串拼接时  使用 es6 模板
        'prefer-template': Rules.ERROR,
        'no-use-before-define': Rules.ERROR,
        /**
         * 对象后面强制需要 跟一个逗号 该规则 只有多行时 起作用
         * let foo = {
         *  bar: 'baz',
         *  qux: 'quz',
         * }
         */
        'comma-dangle': ['error', {
                arrays: 'only-multiline',
                objects: 'only-multiline',
                imports: 'ignore',
                functions: 'ignore',
                exports: 'ignore'
            }],
        // @see http://eslint.cn/docs/4.0.0/rules/consistent-return
        'consistent-return': Rules.ERROR,
        // @see http://eslint.cn/docs/4.0.0/rules/no-underscore-dangle
        'no-underscore-dangle': ['error', {
                'allowAfterThis': true,
                'allowAfterSuper': true
            }],
        // @see http://eslint.cn/docs/4.0.0/rules/no-multi-assign
        'no-multi-assign': Rules.ERROR,
        // @see http://eslint.cn/docs/4.0.0/rules/no-plusplus
        'no-plusplus': Rules.OFF,
        // 如果一个变量重来没有被分配 使用常量
        'prefer-const': Rules.ERROR,
        // @see http://eslint.cn/docs/4.0.0/rules/no-shadow
        'no-shadow': Rules.ERROR,
        // 不允许重新 原生属性的变量
        'no-extend-native': Rules.ERROR,
        'no-console': isProduction ? 'error' : 'off',
        'no-debugger': isProduction ? 'error' : 'off'
    },
    overrides: [
        {
            files: ['*.vue'],
            rules: {
                'vue/script-indent': [
                    'error',
                    2,
                    { 'baseIndent': 1 }
                ],
                indent: 'off'
            }
        }
    ]
};
